import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/cloud-assembly-schema",
    "2.0.0-rc.12",
    __name__[0:-6],
    "cloud-assembly-schema@2.0.0-rc.12.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
